mysql.conversion

Package mysql :: Package conversion |
[hide private]
[frames] | no frames]

# Package conversion

source code

Data type conversion code for the mysql.connection.Connection.execute API.

Connection objects have two objects used for converting Python data types to MySQL parameters and vice-versa.

See mysql.conversion.input for the API for converting Python values to MySQL parameters.

See mysql.conversion.output for the API for converting string values returned from MySQL to Python data types.

Submodules | [hide private]
mysql.conversion.input: Input Conversion converts Python data types to be made appropriate for MySQL parameters. mysql.conversion.output: Output Conversion converts values from MySQL (which are always strings) to Python data types.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.3 $'